@@ -57,5 +57,7 @@ def test_cli_options_match_service_model_validator():
                              'cli-connect-timeout',
                              'no-paginate',
                              'auth-config',
-                             'profile']
+                             'profile',
+                             'cdp-region',
+                             'ensure-ascii']
     assert_equal(sorted(cli_data['options'].keys()), sorted(validated_cli_options))
